@@ -10,11 +10,11 @@ Module::Starter - a simple starter kit for any module
 
 =head1 VERSION
 
-Version 1.71
+Version 1.72
 
 =cut
 
-our $VERSION = '1.71';
+our $VERSION = '1.72';
 
 =head1 SYNOPSIS
 
@@ -53,7 +53,7 @@ It takes a hash of params, as follows:
                                       # or specify more than one builder in an
                                       # arrayref
 
-    license      => $license,  # type of license; defaults to 'perl'
+    license      => $license,  # type of license; defaults to 'artistic2'
     author       => $author,   # author's full name (taken from C<getpwuid> if not provided)
     email        => $email,    # author's email address (taken from C<EMAIL> if not provided)
     ignores_type => $type,     # ignores file type ('generic', 'cvs', 'git', 'hg', 'manifest' )
@@ -141,15 +141,15 @@ L<http://annocpan.org/dist/Module-Starter>
 
 =item * CPAN Ratings
 
-L<http://cpanratings.perl.org/d/Module-Starter>
+L<http://cpanratings.perl.org/dist/Module-Starter>
 
-=item * RT: CPAN's request tracker
+=item * GitHub issue tracker
 
-L<https://github.com/xsawyerx/module-starter/issuesr>
+L<https://github.com/xsawyerx/module-starter/issues>
 
-=item * Search CPAN
+=item * Metacpan
 
-L<http://search.cpan.org/dist/Module-Starter>
+L<https://metacpan.org/release/Module-Starter>
 
 =back
 
