@@ -17,11 +17,11 @@ Module::Starter::Simple - a simple, comprehensive Module::Starter plugin
 
 =head1 VERSION
 
-Version 1.71
+Version 1.72
 
 =cut
 
-our $VERSION = '1.71';
+our $VERSION = '1.72';
 
 =head1 SYNOPSIS
 
@@ -106,7 +106,7 @@ sub create_distro {
     ($self->{email_obfuscated} = $self->{email}) =~ s/@/ at /;
 
     $self->{license}      ||= 'artistic2';
-    $self->{minperl}      ||= 5.006;
+    $self->{minperl}      ||= '5.006';
     $self->{ignores_type} ||= ['generic'];
     $self->{manifest_skip} = !! grep { /manifest/ } @{ $self->{ignores_type} };
     
@@ -753,7 +753,7 @@ sub Makefile_PL_guts {
     
     my $slname = $self->{license_record} ? $self->{license_record}->{slname} : $self->{license};
 
-    my $warnings = sprintf 'warnings%s;', ($self->{fatalize} ? " FATAL => 'all" : '');
+    my $warnings = sprintf 'warnings%s;', ($self->{fatalize} ? " FATAL => 'all'" : '');
 
     return <<"HERE";
 use $self->{minperl};
@@ -768,16 +768,16 @@ WriteMakefile(
     ABSTRACT_FROM    => '$main_pm_file',
     LICENSE          => '$slname',
     PL_FILES         => {},
-    MIN_PERL_VERSION => $self->{minperl},
+    MIN_PERL_VERSION => '$self->{minperl}',
     CONFIGURE_REQUIRES => {
-        'ExtUtils::MakeMaker' => 0,
+        'ExtUtils::MakeMaker' => '0',
     },
     BUILD_REQUIRES => {
-        'Test::More' => 0,
+        'Test::More' => '0',
     },
     PREREQ_PM => {
-        #'ABC'              => 1.6,
-        #'Foo::Bar::Module' => 5.0401,
+        #'ABC'              => '1.6',
+        #'Foo::Bar::Module' => '5.0401',
     },
     dist  => { COMPRESS => 'gzip -9f', SUFFIX => 'gz', },
     clean => { FILES => '$self->{distro}-*' },
@@ -804,7 +804,7 @@ sub MI_Makefile_PL_guts {
     
     my $license_url = $self->{license_record} ? $self->{license_record}->{url} : '';
 
-    my $warnings = sprintf 'warnings%s;', ($self->{fatalize} ? " FATAL => 'all" : '');
+    my $warnings = sprintf 'warnings%s;', ($self->{fatalize} ? " FATAL => 'all'" : '');
 
     return <<"HERE";
 use $self->{minperl};
@@ -817,7 +817,7 @@ all_from '$main_pm_file';
 author   q{$author};
 license  '$self->{license}';
 
-perl_version $self->{minperl};
+perl_version '$self->{minperl}';
 
 tests_recursive('t');
 
@@ -831,16 +831,16 @@ resources (
 );
 
 configure_requires (
-   'Module::Install' => 0,
+   'Module::Install' => '0',
 );
 
 build_requires (
-   'Test::More' => 0,
+   'Test::More' => '0',
 );
 
 requires (
-   #'ABC'              => 1.6,
-   #'Foo::Bar::Module' => 5.0401,
+   #'ABC'              => '1.6',
+   #'Foo::Bar::Module' => '5.0401',
 );
 
 install_as_cpan;
@@ -895,7 +895,7 @@ sub Build_PL_guts {
 
     my $slname = $self->{license_record} ? $self->{license_record}->{slname} : $self->{license};
     
-    my $warnings = sprintf 'warnings%s;', ($self->{fatalize} ? " FATAL => 'all" : '');
+    my $warnings = sprintf 'warnings%s;', ($self->{fatalize} ? " FATAL => 'all'" : '');
 
     return <<"HERE";
 use $self->{minperl};
@@ -910,17 +910,16 @@ my \$builder = Module::Build->new(
     dist_version_from   => '$main_pm_file',
     release_status      => 'stable',
     configure_requires => {
-        'Module::Build' => 0,
+        'Module::Build' => '0',
     },
     build_requires => {
-        'Test::More' => 0,
+        'Test::More' => '0',
     },
     requires => {
-        #'ABC'              => 1.6,
-        #'Foo::Bar::Module' => 5.0401,
+        #'ABC'              => '1.6',
+        #'Foo::Bar::Module' => '5.0401',
     },
     add_to_cleanup     => [ '$self->{distro}-*' ],
-    create_makefile_pl => 'traditional',
 );
 
 \$builder->create_build_script();
@@ -1106,7 +1105,7 @@ sub t_guts {
 
     my %t_files;
     my $minperl = $self->{minperl};
-    my $warnings = sprintf 'warnings%s;', ($self->{fatalize} ? " FATAL => 'all" : '');
+    my $warnings = sprintf 'warnings%s;', ($self->{fatalize} ? " FATAL => 'all'" : '');
 
     my $header = <<"EOH";
 #!perl -T
@@ -1198,7 +1197,7 @@ sub xt_guts {
 
     my %xt_files;
     my $minperl = $self->{minperl};
-    my $warnings = sprintf 'warnings%s;', ($self->{fatalize} ? " FATAL => 'all" : '');
+    my $warnings = sprintf 'warnings%s;', ($self->{fatalize} ? " FATAL => 'all'" : '');
 
     my $header = <<"EOH";
 #!perl -T
@@ -1664,7 +1663,7 @@ sub _module_header {
     my $self = shift;
     my $module = shift;
     my $rtname = shift;
-    my $warnings = sprintf 'warnings%s;', ($self->{fatalize} ? " FATAL => 'all" : '');
+    my $warnings = sprintf 'warnings%s;', ($self->{fatalize} ? " FATAL => 'all'" : '');
 
     my $content = <<"HERE";
 package $module;
